#
# spec file for package elfutils
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           elfutils
Version:        0.153
Release:        0
Summary:        Higher-level library to access ELF
License:        GPL-2.0-with-osi-exception
Group:          System/Libraries
Url:            http://elfutils.fedorahosted.org
Source:         elfutils-%{version}.tar.bz2
Source1:        README-BEFORE-ADDING-PATCHES
Source2:        baselibs.conf
Patch1:         elfutils-portability.patch
Patch2:         elfutils-robustify.patch
Patch3:         elfutils-no-po-test-build.diff
Patch4:         libebl-prototype-fix.diff
Patch5:         elfutils-uninitialized.diff
Patch6:         elfutils-0.137-dwarf-header-check-fix.diff
Patch7:         elfutils-0.148-dont-crash.diff
Patch8:         elfutils-revert-portability-scanf.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libbz2-devel
BuildRequires:  xz-devel
BuildRequires:  zlib-devel

%description
This package provides a higher-level library to access ELF files. This
is a part of elfutils package.

%package -n libasm1
Summary:        A collection of utilities and DSOs to handle compiled objects
Group:          Development/Tools/Other

%description -n libasm1
Elfutils is a collection of utilities, including ld (a linker), nm (for
listing symbols from object files), size (for listing the section sizes
of an object or archive file), strip (for discarding symbols), readline
(the see the raw ELF file structures), and elflint (to check for
well-formed ELF files).  Also included are numerous helper libraries
which implement DWARF, ELF, and machine-specific ELF handling.

%package -n libasm-devel
Summary:        A collection of utilities and DSOs to handle compiled objects
Group:          Development/Tools/Other
Requires:       glibc-devel
Requires:       libasm1 = %{version}

%description -n libasm-devel
Elfutils is a collection of utilities, including ld (a linker), nm (for
listing symbols from object files), size (for listing the section sizes
of an object or archive file), strip (for discarding symbols), readline
(the see the raw ELF file structures), and elflint (to check for
well-formed ELF files).  Also included are numerous helper libraries
which implement DWARF, ELF, and machine-specific ELF handling.

%package -n libebl1
Summary:        A collection of utilities and DSOs to handle compiled objects
Group:          Development/Tools/Other
Provides:       libebl = %{version}
Obsoletes:      libebl < %{version}

%description -n libebl1
Elfutils is a collection of utilities, including ld (a linker), nm (for
listing symbols from object files), size (for listing the section sizes
of an object or archive file), strip (for discarding symbols), readline
(the see the raw ELF file structures), and elflint (to check for
well-formed ELF files).  Also included are numerous helper libraries
which implement DWARF, ELF, and machine-specific ELF handling.

%package -n libebl-devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libdw-devel = %{version}
Requires:       libebl1 = %{version}

%description -n libebl-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package -n libelf1
Summary:        Library to read and write ELF files
Group:          System/Libraries

%description -n libelf1
This package provides a high-level library to read and write ELF files.
This is a part of elfutils package.

%package -n libelf-devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libelf1 = %{version}
Conflicts:      libelf0-devel

%description -n libelf-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package -n libdw1
Summary:        Library to access DWARF debugging information
Group:          System/Libraries

%description -n libdw1
This package provides a high-level library to access the DWARF debugging
information.  This is a part of elfutils package.

%package -n libdw-devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libdw1 = %{version}
Requires:       libelf-devel = %{version}

%description -n libdw-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q -n elfutils-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1 -R

%build
# Change DATE/TIME macros to use last change time of elfutils.changes
# See http://lists.opensuse.org/opensuse-factory/2011-05/msg00304.html
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find . -type f -regex ".*\.c\|.*\.cpp\|.*\.h" -exec sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" {} +
%configure --program-prefix=eu-
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
ls -lR $RPM_BUILD_ROOT%{_libdir}/libelf*

%post -n libebl1 -p /sbin/ldconfig

%post -n libelf1 -p /sbin/ldconfig

%post -n libdw1 -p /sbin/ldconfig

%postun -n libebl1 -p /sbin/ldconfig

%postun -n libelf1 -p /sbin/ldconfig

%postun -n libdw1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING EXCEPTION NEWS NOTES README THANKS TODO
%{_bindir}/*

%files -n libasm1
%defattr(-,root,root)
%{_libdir}/libasm.so.*
%{_libdir}/libasm-%{version}.so

%files -n libasm-devel
%defattr(-,root,root)
%{_libdir}/libasm.so
%{_libdir}/libasm.a
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/libasm.h

%files -n libebl1
%defattr(-,root,root)
%{_libdir}/elfutils

%files -n libebl-devel
%defattr(-,root,root)
%{_libdir}/libebl.a
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/libebl.h

%files -n libelf1
%defattr(-,root,root)
%{_libdir}/libelf.so.*
%{_libdir}/libelf-%{version}.so

%files -n libelf-devel
%defattr(-,root,root)
%{_libdir}/libelf.so
%{_libdir}/libelf.a
#%{_libdir}/libelf_pic.a
%{_includedir}/libelf.h
%{_includedir}/gelf.h
%{_includedir}/nlist.h
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/elf-knowledge.h
%{_includedir}/elfutils/version.h

%files -n libdw1
%defattr(-,root,root)
%{_libdir}/libdw.so.*
%{_libdir}/libdw-%{version}.so

%files -n libdw-devel
%defattr(-,root,root)
%{_libdir}/libdw.a
%{_libdir}/libdw.so
%{_includedir}/dwarf.h
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/libdw.h
%{_includedir}/elfutils/libdwfl.h

%changelog
